Pypims is built upon [hipims-cuda](https://github.com/HEMLab/hipims) of [HEMLab](https://www.hemlab.org).

List of authors (ranked by first letter of surname) of pypims are:

* Xiaodong Ming
* Xilin Xia

Full history of contributions can be found on https://github.com/pypims/pypims/graphs/contributors.